get_EC: Function to get EC values given a model.

View source: R/get-ec.R

get_ECR Documentation

Function to get EC values given a model.

Description

Function to get EC values given a model.

Usage

get_EC(x, response = c(10, 50, 90), disp = TRUE)

Arguments

x

a model generated from the drm function of the drc package

response

a numeric vector specifying at what response levels to generate an EC value. Defaults to 10, 50 and 90 (percent).

disp

display the results?

Details

This function is a wrapper for ED.

Value

a data frame with the Estimate and standard error for each response value.

Author(s)

Zhian N. Kamvar


ezec documentation built on March 10, 2026, 1:07 a.m.