Function to generate a dose-response model from a data frame.
get_drm(x, form = NULL, model = c("LL.3", "LL.4", "W1.4", "W2.4"),
idcol = "ID")a data frame that has at least the columns listed in the form
argument (e.g. "response" and "dose", see examples).
a formula specifying the column names for the response and dose. Defaults to NULL.
one of 4 options:
LL.3 = Log Logistic 3 parameter with a lower limit of 0.
LL.4 = Log Logistic 4 parameter with lower limit estimated.
W1.4 = Weibul 4 parameter type 1.
W2.4 = Weibul 4 parameter type 2.
the name of the column that identifies the samples (case sensitive).
Zhian N. Kamvar
A wrapper function for drm, this will attempt to
catch errors generated due to non-finite responses. When these are
encounterd, a message that the model was not evaluated will be printed to
the screen and NA will be returned.