| ezec | R Documentation |
Because fungicide resistance is an important phenotypic trait for fungi and oomycetes, it is necessary to have a standardized method of statistically analyzing the Effective Concentration (EC) values. This package is designed for those who are not terribly familiar with R to be able to analyze and plot an entire set of isolates using the 'drc' package.
The package ezec is not a revolutionary work. It
simply is a wrapper for the drc package that makes life a little
easier when it comes to calculating a simple EC 50. The main function of
the package is EC_table. This function will do as it says and
automatically produce a table to EC values for each isolate in your sample.
Data is expected to exist in a table with at least three columns:
Sample ID
Dosage
Response value (Growth)
Any other columns in your data are optional. An example data set
is dummydata.
Maintainer: Zhian N. Kamvar zkamvar@gmail.com
Other contributors:
Niklaus J. Grunwald grunwaln@science.oregonstate.edu [thesis advisor, contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.