Learn R Programming

ezec (version 1.0.1)

get_EC: Function to get EC values given a model.

Description

Function to get EC values given a model.

Usage

get_EC(x, response = c(10, 50, 90), disp = TRUE)

Value

a data frame with the Estimate and standard error for each response value.

Arguments

x

a model generated from the drm function of the drc package

response

a numeric vector specifying at what response levels to generate an EC value. Defaults to 10, 50 and 90 (percent).

disp

display the results?

Author

Zhian N. Kamvar

Details

This function is a wrapper for ED.